from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import MapKit

MKLocalSearchCompletionHandler = b"v@@"


class TestMKLocalSearch(TestCase):
    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(MapKit.MKLocalSearch, objc.objc_class)

        self.assertArgIsBlock(
            MapKit.MKLocalSearch.startWithCompletionHandler_,
            0,
            MKLocalSearchCompletionHandler,
        )
        self.assertResultIsBOOL(MapKit.MKLocalSearch.isSearching)



from PyObjCTools.TestSupport import TestCase, min_os_level

import MapKit


class TestMKCircle(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(MapKit.MKErrorCode)
        self.assertIsEnumType(MapKit.MKFeatureVisibility)
        self.assertIsEnumType(MapKit.MKMapType)

    @min_os_level("10.9")
    def testConstants(self):
        self.assertEqual(MapKit.MKMapTypeStandard, 0)
        self.assertEqual(MapKit.MKMapTypeSatellite, 1)
        self.assertEqual(MapKit.MKMapTypeHybrid, 2)

        self.assertIsInstance(MapKit.MKErrorDomain, str)

        self.assertEqual(MapKit.MKErrorUnknown, 1)
        self.assertEqual(MapKit.MKErrorServerFailure, 2)
        self.assertEqual(MapKit.MKErrorLoadingThrottled, 3)
        self.assertEqual(MapKit.MKErrorPlacemarkNotFound, 4)
        self.assertEqual(MapKit.MKErrorDirectionsNotFound, 5)
        self.assertEqual(MapKit.MKErrorDecodingFailed, 6)

        self.assertEqual(MapKit.MKFeatureVisibilityAdaptive, 0)
        self.assertEqual(MapKit.MKFeatureVisibilityHidden, 1)
        self.assertEqual(MapKit.MKFeatureVisibilityVisible, 2)

    @min_os_level("10.11")
    def testConstants10_11(self):
        self.assertEqual(MapKit.MKMapTypeSatelliteFlyover, 3)
        self.assertEqual(MapKit.MKMapTypeHybridFlyover, 4)
        self.assertEqual(MapKit.MKMapTypeMutedStandard, 5)



from PyObjCTools.TestSupport import TestCase, min_os_level

import MapKit


class TestMKStandardMapConfiguration(TestCase):
    def test_constants(self):
        self.assertIsEnumType(MapKit.MKStandardMapEmphasisStyle)
        self.assertEqual(MapKit.MKStandardMapEmphasisStyleDefault, 0)
        self.assertEqual(MapKit.MKStandardMapEmphasisStyleMuted, 1)

    @min_os_level("13.0")
    def test_methods13_0(self):
        self.assertResultIsBOOL(MapKit.MKStandardMapConfiguration.showsTraffic)
        self.assertArgIsBOOL(MapKit.MKStandardMapConfiguration.setShowsTraffic_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level
import MapKit


class TestMKOverlayHelper(MapKit.NSObject):
    def intersectsMapRect_(self, r):
        return 1

    def canReplaceMapContent(self):
        return 0

    def boundingMapRect(self):
        return 0

    def coordinate(self):
        return 0


class TestMKOverlay(TestCase):
    @min_os_level("10.9")
    def testProtocols(self):
        self.assertProtocolExists("MKOverlay")

    def test_protocol_methods(self):
        self.assertResultIsBOOL(TestMKOverlayHelper.intersectsMapRect_)
        self.assertArgHasType(
            TestMKOverlayHelper.intersectsMapRect_, 0, MapKit.MKMapRect.__typestr__
        )
        self.assertResultIsBOOL(TestMKOverlayHelper.canReplaceMapContent)
        self.assertResultHasType(
            TestMKOverlayHelper.coordinate, MapKit.CLLocationCoordinate2D.__typestr__
        )
        self.assertResultHasType(
            TestMKOverlayHelper.boundingMapRect, MapKit.MKMapRect.__typestr__
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import MapKit


class TestMKLocalSearchRequest(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(MapKit.MKLocalSearchResultType)

    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(MapKit.MKLocalSearchRequest, objc.objc_class)

    def test_constants(self):
        self.assertEqual(MapKit.MKLocalSearchResultTypeAddress, 1 << 0)
        self.assertEqual(MapKit.MKLocalSearchResultTypePointOfInterest, 1 << 1)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import MapKit


class TestMKShape(TestCase):
    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(MapKit.MKShape, objc.objc_class)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import MapKit


class TestMKMultiPoint(TestCase):
    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(MapKit.MKMultiPoint, objc.objc_class)

        self.assertResultIsVariableSize(
            MapKit.MKMultiPoint.points
        )  # XXX: Gone in 10.11 SDK headers?

        self.assertArgSizeInArg(MapKit.MKMultiPoint.getCoordinates_range_, 0, 1)
        self.assertArgIsOut(MapKit.MKMultiPoint.getCoordinates_range_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import MapKit


class TestMKTileOverlay(TestCase):
    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(MapKit.MKTileOverlay, objc.objc_class)

        self.assertResultIsBOOL(MapKit.MKTileOverlay.isGeometryFlipped)
        self.assertArgIsBOOL(MapKit.MKTileOverlay.setGeometryFlipped_, 0)

        self.assertResultIsBOOL(MapKit.MKTileOverlay.canReplaceMapContent)
        self.assertArgIsBOOL(MapKit.MKTileOverlay.setCanReplaceMapContent_, 0)

        self.assertArgIsBlock(MapKit.MKTileOverlay.loadTileAtPath_result_, 1, b"v@@")

    @min_os_level("10.9")
    def testStructs(self):
        c = MapKit.MKTileOverlayPath()
        self.assertIsInstance(c.x, int)
        self.assertIsInstance(c.y, int)
        self.assertIsInstance(c.z, int)
        self.assertIsInstance(c.contentScaleFactor, float)
        self.assertPickleRoundTrips(c)



from PyObjCTools.TestSupport import TestCase

import MapKit


class TestMKMapConfiguration(TestCase):
    def test_constants(self):
        self.assertIsEnumType(MapKit.MKMapElevationStyle)
        self.assertEqual(MapKit.MKMapElevationStyleFlat, 0)
        self.assertEqual(MapKit.MKMapElevationStyleRealistic, 1)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import MapKit


class TestMKMapCamera(TestCase):
    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(MapKit.MKMapCamera, objc.objc_class)

    @min_os_level("13.0")
    def test_methods13_0(self):
        self.assertArgIsBOOL(
            MapKit.MKMapCamera.cameraLookingAtMapItem_forViewSize_allowPitch_, 2
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import MapKit


class TestMKAnnotationHelper(MapKit.NSObject):
    def coordinate(self):
        return 1

    def setCoordinate_(self, value):
        pass


class TestMKAnnotation(TestCase):
    @min_os_level("10.9")
    def testProtocols(self):
        self.assertProtocolExists("MKAnnotation")

        self.assertResultHasType(
            TestMKAnnotationHelper.coordinate, MapKit.CLLocationCoordinate2D.__typestr__
        )
        self.assertArgHasType(
            TestMKAnnotationHelper.setCoordinate_,
            0,
            MapKit.CLLocationCoordinate2D.__typestr__,
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import MapKit


class TestMKOverlayPathRenderer(TestCase):
    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(MapKit.MKOverlayPathRenderer, objc.objc_class)

    @min_os_level("10.15")
    def test_methods(self):
        self.assertResultIsBOOL(MapKit.MKOverlayPathRenderer.shouldRasterize)
        self.assertArgIsBOOL(MapKit.MKOverlayPathRenderer.setShouldRasterize_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level

import MapKit


class TestMKPointOfInterestFilter(TestCase):
    @min_os_level("10.15")
    def test_methods(self):
        self.assertResultIsBOOL(MapKit.MKPointOfInterestFilter.includesCategory_)
        self.assertResultIsBOOL(MapKit.MKPointOfInterestFilter.excludesCategory_)



from PyObjCTools.TestSupport import TestCase, min_os_level

import MapKit


class TestMKMapCameraZoomRange(TestCase):
    @min_os_level("10.15")
    def test_constants(self):
        self.assertIsInstance(MapKit.MKMapCameraZoomDefault, float)



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level

import MapKit


class TestMKGeoJSONSerialization(TestCase):
    @min_os_level("10.15")
    def test_methods(self):
        self.assertArgIsOut(MapKit.MKGeoJSONDecoder.geoJSONObjectsWithData_error_, 1)

    @min_sdk_level("10.15")
    def test_protocols(self):
        self.assertProtocolExists("MKGeoJSONObject")



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import MapKit


class TestMKLocalSearchCompleter(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(MapKit.MKLocalSearchCompleterResultType)
        self.assertIsEnumType(MapKit.MKSearchCompletionFilterType)

    def testConstants(self):
        self.assertEqual(MapKit.MKSearchCompletionFilterTypeLocationsAndQueries, 0)
        self.assertEqual(MapKit.MKSearchCompletionFilterTypeLocationsOnly, 1)

        self.assertEqual(MapKit.MKLocalSearchCompleterResultTypeAddress, 1 << 0)
        self.assertEqual(MapKit.MKLocalSearchCompleterResultTypePointOfInterest, 1 << 1)
        self.assertEqual(MapKit.MKLocalSearchCompleterResultTypeQuery, 1 << 2)

    @min_os_level("10.11")
    def testMethods(self):
        self.assertResultIsBOOL(MapKit.MKLocalSearchCompleter.isSearching)

    @min_sdk_level("10.12")
    def testProtocols(self):
        self.assertProtocolExists("MKLocalSearchCompleterDelegate")



from PyObjCTools.TestSupport import TestCase, min_os_level

import MapKit


class TestMKHybridMapConfiguration(TestCase):
    @min_os_level("13.0")
    def test_methods13_0(self):
        self.assertResultIsBOOL(MapKit.MKHybridMapConfiguration.showsTraffic)
        self.assertArgIsBOOL(MapKit.MKHybridMapConfiguration.setShowsTraffic_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import MapKit


class TestMKPolyline(TestCase):
    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(MapKit.MKPolyline, objc.objc_class)

        self.assertArgSizeInArg(MapKit.MKPolyline.polylineWithPoints_count_, 0, 1)
        self.assertArgIsIn(MapKit.MKPolyline.polylineWithPoints_count_, 0)

        self.assertArgSizeInArg(MapKit.MKPolyline.polylineWithCoordinates_count_, 0, 1)
        self.assertArgIsIn(MapKit.MKPolyline.polylineWithCoordinates_count_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level

import MapKit


class TestMKLookAroundViewController(TestCase):
    def test_constants(self):
        self.assertIsEnumType(MapKit.MKLookAroundBadgePosition)

        self.assertEqual(MapKit.MKLookAroundBadgePositionTopLeading, 0)
        self.assertEqual(MapKit.MKLookAroundBadgePositionTopTrailing, 1)
        self.assertEqual(MapKit.MKLookAroundBadgePositionBottomTrailing, 2)

    @min_sdk_level("13.0")
    def test_protocols13_0(self):
        self.assertProtocolExists("MKLookAroundViewControllerDelegate")

    @min_os_level("13.0")
    def test_methods13_0(self):
        self.assertResultIsBOOL(MapKit.MKLookAroundViewController.isNavigationEnabled)
        self.assertArgIsBOOL(MapKit.MKLookAroundViewController.setNavigationEnabled_, 0)

        self.assertResultIsBOOL(MapKit.MKLookAroundViewController.showsRoadLabels)
        self.assertArgIsBOOL(MapKit.MKLookAroundViewController.setShowsRoadLabels_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import MapKit


class TestMKPinAnnotationView(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(MapKit.MKPinAnnotationColor)

    @min_os_level("10.9")
    def testConstants(self):
        self.assertEqual(MapKit.MKPinAnnotationColorRed, 0)
        self.assertEqual(MapKit.MKPinAnnotationColorGreen, 1)
        self.assertEqual(MapKit.MKPinAnnotationColorPurple, 2)

    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(MapKit.MKPinAnnotationView, objc.objc_class)

        self.assertResultIsBOOL(MapKit.MKPinAnnotationView.animatesDrop)
        self.assertArgIsBOOL(MapKit.MKPinAnnotationView.setAnimatesDrop_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import MapKit

MKDirectionsHandler = b"v@@"
MKETAHandler = b"v@@"


class TestMKDirections(TestCase):
    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(MapKit.MKDirections, objc.objc_class)

        self.assertArgIsBlock(
            MapKit.MKDirections.calculateDirectionsWithCompletionHandler_,
            0,
            MKDirectionsHandler,
        )
        self.assertArgIsBlock(
            MapKit.MKDirections.calculateETAWithCompletionHandler_, 0, MKETAHandler
        )

        self.assertResultIsBOOL(MapKit.MKDirections.isCalculating)



from PyObjCTools.TestSupport import TestCase, min_os_level

import MapKit


class TestMKLookAroundSnapshotter(TestCase):
    @min_os_level("13.0")
    def test_methods13_0(self):
        self.assertArgIsBlock(
            MapKit.MKLookAroundSnapshotter.getSnapshotWithCompletionHandler_, 0, b"v@@"
        )

        self.assertResultIsBOOL(MapKit.MKLookAroundSnapshotter.isLoading)



from PyObjCTools.TestSupport import TestCase, min_os_level

import MapKit


class TestMKPointOfInterestCategory(TestCase):
    def test_typed_enum(self):
        self.assertIsTypedEnum(MapKit.MKPointOfInterestCategory, str)

    @min_os_level("10.15")
    def test_constants(self):
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryAirport, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryAmusementPark, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryAquarium, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryATM, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryBakery, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryBank, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryBeach, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryBrewery, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryCafe, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryCampground, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryCarRental, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryEVCharger, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryFireStation, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryFitnessCenter, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryFoodMarket, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryGasStation, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryHospital, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryHotel, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryLaundry, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryLibrary, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryMarina, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryMovieTheater, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryMuseum, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryNationalPark, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryNightlife, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryPark, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryParking, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryPharmacy, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryPolice, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryPostOffice, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryPublicTransport, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryRestaurant, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryRestroom, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategorySchool, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryStadium, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryStore, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryTheater, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryUniversity, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryWinery, str)
        self.assertIsInstance(MapKit.MKPointOfInterestCategoryZoo, str)
